# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_privateendpoints.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4azure/azure_microsoft_network_privateendpoints.proto\x12\x34oak9.tython.azure.microsoft_network_privateendpoints\x1a\x13shared/shared.proto\"\x97\x02\n\"Microsoft_Network_privateEndpoints\x12\x61\n\x11private_endpoints\x18\x01 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network_privateendpoints.PrivateEndpoints\x12\x8d\x01\n)private_endpoints_private_dns_zone_groups\x18\x02 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_privateendpoints.PrivateEndpointsPrivateDnsZoneGroups\"\x14\n\x06Subnet\x12\n\n\x02id\x18\x01 \x01(\t\"\xdb\x01\n$PrivateEndpointsPrivateDnsZoneGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12l\n\x18private_dns_zone_configs\x18\x03 \x03(\x0b\x32J.oak9.tython.azure.microsoft_network_privateendpoints.PrivateDnsZoneConfig\"A\n\x14PrivateDnsZoneConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13private_dns_zone_id\x18\x02 \x01(\t\"\xa0\x06\n\x10PrivateEndpoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12^\n\x04tags\x18\x04 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_privateendpoints.PrivateEndpoints.TagsEntry\x12\x61\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network_privateendpoints.ExtendedLocation\x12L\n\x06subnet\x18\x06 \x01(\x0b\x32<.oak9.tython.azure.microsoft_network_privateendpoints.Subnet\x12|\n private_link_service_connections\x18\x07 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_privateendpoints.PrivateLinkServiceConnection\x12\x83\x01\n\'manual_private_link_service_connections\x18\x08 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_privateendpoints.PrivateLinkServiceConnection\x12q\n\x12\x63ustom_dns_configs\x18\t \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privateendpoints.CustomDnsConfigPropertiesFormat\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x1f\x43ustomDnsConfigPropertiesFormat\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x14\n\x0cip_addresses\x18\x02 \x03(\t\"\x82\x02\n\x1cPrivateLinkServiceConnection\x12\x1f\n\x17private_link_service_id\x18\x01 \x01(\t\x12\x11\n\tgroup_ids\x18\x02 \x03(\t\x12\x17\n\x0frequest_message\x18\x03 \x01(\t\x12\x86\x01\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32W.oak9.tython.azure.microsoft_network_privateendpoints.PrivateLinkServiceConnectionState\x12\x0c\n\x04name\x18\x05 \x01(\t\"b\n!PrivateLinkServiceConnectionState\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10\x61\x63tions_required\x18\x03 \x01(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_privateendpoints_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVATEENDPOINTS_TAGSENTRY._options = None
  _PRIVATEENDPOINTS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_PRIVATEENDPOINTS._serialized_start=132
  _MICROSOFT_NETWORK_PRIVATEENDPOINTS._serialized_end=411
  _SUBNET._serialized_start=413
  _SUBNET._serialized_end=433
  _PRIVATEENDPOINTSPRIVATEDNSZONEGROUPS._serialized_start=436
  _PRIVATEENDPOINTSPRIVATEDNSZONEGROUPS._serialized_end=655
  _PRIVATEDNSZONECONFIG._serialized_start=657
  _PRIVATEDNSZONECONFIG._serialized_end=722
  _PRIVATEENDPOINTS._serialized_start=725
  _PRIVATEENDPOINTS._serialized_end=1525
  _PRIVATEENDPOINTS_TAGSENTRY._serialized_start=1482
  _PRIVATEENDPOINTS_TAGSENTRY._serialized_end=1525
  _CUSTOMDNSCONFIGPROPERTIESFORMAT._serialized_start=1527
  _CUSTOMDNSCONFIGPROPERTIESFORMAT._serialized_end=1596
  _PRIVATELINKSERVICECONNECTION._serialized_start=1599
  _PRIVATELINKSERVICECONNECTION._serialized_end=1857
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=1859
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=1957
  _EXTENDEDLOCATION._serialized_start=1959
  _EXTENDEDLOCATION._serialized_end=2005
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Route(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    DESTINATION_IPV6_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    EGRESS_ONLY_INTERNET_GATEWAY_ID_FIELD_NUMBER: builtins.int
    GATEWAY_ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    NAT_GATEWAY_ID_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_ID_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_ID_FIELD_NUMBER: builtins.int
    TRANSIT_GATEWAY_ID_FIELD_NUMBER: builtins.int
    VPC_PEERING_CONNECTION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_cidr_block: builtins.str
    destination_ipv6_cidr_block: builtins.str
    egress_only_internet_gateway_id: builtins.str
    gateway_id: builtins.str
    instance_id: builtins.str
    nat_gateway_id: builtins.str
    network_interface_id: builtins.str
    route_table_id: builtins.str
    transit_gateway_id: builtins.str
    vpc_peering_connection_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_cidr_block: builtins.str = ...,
        destination_ipv6_cidr_block: builtins.str = ...,
        egress_only_internet_gateway_id: builtins.str = ...,
        gateway_id: builtins.str = ...,
        instance_id: builtins.str = ...,
        nat_gateway_id: builtins.str = ...,
        network_interface_id: builtins.str = ...,
        route_table_id: builtins.str = ...,
        transit_gateway_id: builtins.str = ...,
        vpc_peering_connection_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_cidr_block", b"destination_cidr_block", "destination_ipv6_cidr_block", b"destination_ipv6_cidr_block", "egress_only_internet_gateway_id", b"egress_only_internet_gateway_id", "gateway_id", b"gateway_id", "instance_id", b"instance_id", "nat_gateway_id", b"nat_gateway_id", "network_interface_id", b"network_interface_id", "resource_info", b"resource_info", "route_table_id", b"route_table_id", "transit_gateway_id", b"transit_gateway_id", "vpc_peering_connection_id", b"vpc_peering_connection_id"]) -> None: ...

global___Route = Route

@typing_extensions.final
class EC2_Route(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTE_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_FIELD_NUMBER: builtins.int
    @property
    def route(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]: ...
    @property
    def route_table(self) -> global___RouteTable: ...
    def __init__(
        self,
        *,
        route: collections.abc.Iterable[global___Route] | None = ...,
        route_table: global___RouteTable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["route_table", b"route_table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["route", b"route", "route_table", b"route_table"]) -> None: ...

global___EC2_Route = EC2_Route

@typing_extensions.final
class RouteTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags", "vpc_id", b"vpc_id"]) -> None: ...

global___RouteTable = RouteTable



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agcp/gcp_compute_node.proto\x12\x1coak9.tython.gcp.compute_node\x1a\x13shared/shared.proto\"X\n\"ComputeNodeGroupXAutoscalingPolicy\x12\x11\n\tmax_nodes\x18\x01 \x01(\x01\x12\x11\n\tmin_nodes\x18\x02 \x01(\x01\x12\x0c\n\x04mode\x18\x03 \x01(\t\"8\n\"ComputeNodeGroupXMaintenanceWindow\x12\x12\n\nstart_time\x18\x01 \x01(\t\"K\n\x19\x43omputeNodeGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa6\x04\n\x10\x43omputeNodeGroup\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x14\n\x0cinitial_size\x18\x04 \x01(\x01\x12\x1a\n\x12maintenance_policy\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x15\n\rnode_template\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12\x0c\n\x04size\x18\n \x01(\x01\x12\x0c\n\x04zone\x18\x0b \x01(\t\x12\\\n\x12\x61utoscaling_policy\x18\x0c \x01(\x0b\x32@.oak9.tython.gcp.compute_node.ComputeNodeGroupXAutoscalingPolicy\x12\\\n\x12maintenance_window\x18\r \x01(\x0b\x32@.oak9.tython.gcp.compute_node.ComputeNodeGroupXMaintenanceWindow\x12I\n\x08timeouts\x18\x0e \x01(\x0b\x32\x37.oak9.tython.gcp.compute_node.ComputeNodeGroupXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n\'ComputeNodeTemplateXNodeTypeFlexibility\x12\x0c\n\x04\x63pus\x18\x01 \x01(\t\x12\x11\n\tlocal_ssd\x18\x02 \x01(\t\x12\x0e\n\x06memory\x18\x03 \x01(\t\"1\n!ComputeNodeTemplateXServerBinding\x12\x0c\n\x04type\x18\x01 \x01(\t\">\n\x1c\x43omputeNodeTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xae\x05\n\x13\x43omputeNodeTemplate\x12\x1b\n\x13\x63pu_overcommit_type\x18\x01 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12g\n\x14node_affinity_labels\x18\x06 \x03(\x0b\x32I.oak9.tython.gcp.compute_node.ComputeNodeTemplate.NodeAffinityLabelsEntry\x12\x11\n\tnode_type\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0e\n\x06region\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12\x64\n\x15node_type_flexibility\x18\x0b \x01(\x0b\x32\x45.oak9.tython.gcp.compute_node.ComputeNodeTemplateXNodeTypeFlexibility\x12W\n\x0eserver_binding\x18\x0c \x01(\x0b\x32?.oak9.tython.gcp.compute_node.ComputeNodeTemplateXServerBinding\x12L\n\x08timeouts\x18\r \x01(\x0b\x32:.oak9.tython.gcp.compute_node.ComputeNodeTemplateXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17NodeAffinityLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_node_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTENODETEMPLATE_NODEAFFINITYLABELSENTRY._options = None
  _COMPUTENODETEMPLATE_NODEAFFINITYLABELSENTRY._serialized_options = b'8\001'
  _COMPUTENODEGROUPXAUTOSCALINGPOLICY._serialized_start=81
  _COMPUTENODEGROUPXAUTOSCALINGPOLICY._serialized_end=169
  _COMPUTENODEGROUPXMAINTENANCEWINDOW._serialized_start=171
  _COMPUTENODEGROUPXMAINTENANCEWINDOW._serialized_end=227
  _COMPUTENODEGROUPXTIMEOUTS._serialized_start=229
  _COMPUTENODEGROUPXTIMEOUTS._serialized_end=304
  _COMPUTENODEGROUP._serialized_start=307
  _COMPUTENODEGROUP._serialized_end=857
  _COMPUTENODETEMPLATEXNODETYPEFLEXIBILITY._serialized_start=859
  _COMPUTENODETEMPLATEXNODETYPEFLEXIBILITY._serialized_end=949
  _COMPUTENODETEMPLATEXSERVERBINDING._serialized_start=951
  _COMPUTENODETEMPLATEXSERVERBINDING._serialized_end=1000
  _COMPUTENODETEMPLATEXTIMEOUTS._serialized_start=1002
  _COMPUTENODETEMPLATEXTIMEOUTS._serialized_end=1064
  _COMPUTENODETEMPLATE._serialized_start=1067
  _COMPUTENODETEMPLATE._serialized_end=1753
  _COMPUTENODETEMPLATE_NODEAFFINITYLABELSENTRY._serialized_start=1696
  _COMPUTENODETEMPLATE_NODEAFFINITYLABELSENTRY._serialized_end=1753
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AppSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    SSH_KEY_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    password: builtins.str
    revision: builtins.str
    ssh_key: builtins.str
    url: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        password: builtins.str = ...,
        revision: builtins.str = ...,
        ssh_key: builtins.str = ...,
        url: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "revision", b"revision", "ssh_key", b"ssh_key", "url", b"url", "username", b"username"]) -> None: ...

global___AppSource = AppSource

@typing_extensions.final
class AppDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARN_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    arn: builtins.str
    database_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        arn: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arn", b"arn", "database_name", b"database_name", "resource_info", b"resource_info"]) -> None: ...

global___AppDataSource = AppDataSource

@typing_extensions.final
class AppEnvironmentVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    SECURE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    secure: builtins.bool
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        secure: builtins.bool = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "secure", b"secure", "value", b"value"]) -> None: ...

global___AppEnvironmentVariable = AppEnvironmentVariable

@typing_extensions.final
class AppSslConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    CHAIN_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate: builtins.str
    chain: builtins.str
    private_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate: builtins.str = ...,
        chain: builtins.str = ...,
        private_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "chain", b"chain", "private_key", b"private_key", "resource_info", b"resource_info"]) -> None: ...

global___AppSslConfiguration = AppSslConfiguration

@typing_extensions.final
class App(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APP_SOURCE_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    DATA_SOURCES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOMAINS_FIELD_NUMBER: builtins.int
    ENABLE_SSL_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SHORTNAME_FIELD_NUMBER: builtins.int
    SSL_CONFIGURATION_FIELD_NUMBER: builtins.int
    STACK_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def app_source(self) -> global___AppSource: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def data_sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppDataSource]: ...
    description: builtins.str
    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_ssl: builtins.bool
    @property
    def environment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEnvironmentVariable]: ...
    name: builtins.str
    shortname: builtins.str
    @property
    def ssl_configuration(self) -> global___AppSslConfiguration: ...
    stack_id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        app_source: global___AppSource | None = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        data_sources: collections.abc.Iterable[global___AppDataSource] | None = ...,
        description: builtins.str = ...,
        domains: collections.abc.Iterable[builtins.str] | None = ...,
        enable_ssl: builtins.bool = ...,
        environment: collections.abc.Iterable[global___AppEnvironmentVariable] | None = ...,
        name: builtins.str = ...,
        shortname: builtins.str = ...,
        ssl_configuration: global___AppSslConfiguration | None = ...,
        stack_id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_source", b"app_source", "resource_info", b"resource_info", "ssl_configuration", b"ssl_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_source", b"app_source", "attributes", b"attributes", "data_sources", b"data_sources", "description", b"description", "domains", b"domains", "enable_ssl", b"enable_ssl", "environment", b"environment", "name", b"name", "resource_info", b"resource_info", "shortname", b"shortname", "ssl_configuration", b"ssl_configuration", "stack_id", b"stack_id", "type", b"type"]) -> None: ...

global___App = App

@typing_extensions.final
class OpsWorks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_FIELD_NUMBER: builtins.int
    ELASTIC_LOAD_BALANCER_ATTACHMENT_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    LAYER_FIELD_NUMBER: builtins.int
    STACK_FIELD_NUMBER: builtins.int
    USER_PROFILE_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    @property
    def app(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___App]: ...
    @property
    def elastic_load_balancer_attachment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ElasticLoadBalancerAttachment]: ...
    @property
    def instance(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Instance]: ...
    @property
    def layer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Layer]: ...
    @property
    def stack(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stack]: ...
    @property
    def user_profile(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserProfile]: ...
    @property
    def volume(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Volume]: ...
    def __init__(
        self,
        *,
        app: collections.abc.Iterable[global___App] | None = ...,
        elastic_load_balancer_attachment: collections.abc.Iterable[global___ElasticLoadBalancerAttachment] | None = ...,
        instance: collections.abc.Iterable[global___Instance] | None = ...,
        layer: collections.abc.Iterable[global___Layer] | None = ...,
        stack: collections.abc.Iterable[global___Stack] | None = ...,
        user_profile: collections.abc.Iterable[global___UserProfile] | None = ...,
        volume: collections.abc.Iterable[global___Volume] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app", "elastic_load_balancer_attachment", b"elastic_load_balancer_attachment", "instance", b"instance", "layer", b"layer", "stack", b"stack", "user_profile", b"user_profile", "volume", b"volume"]) -> None: ...

global___OpsWorks = OpsWorks

@typing_extensions.final
class ElasticLoadBalancerAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ELASTIC_LOAD_BALANCER_NAME_FIELD_NUMBER: builtins.int
    LAYER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    elastic_load_balancer_name: builtins.str
    layer_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        elastic_load_balancer_name: builtins.str = ...,
        layer_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elastic_load_balancer_name", b"elastic_load_balancer_name", "layer_id", b"layer_id", "resource_info", b"resource_info"]) -> None: ...

global___ElasticLoadBalancerAttachment = ElasticLoadBalancerAttachment

@typing_extensions.final
class InstanceEbsBlockDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELETE_ON_TERMINATION_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delete_on_termination: builtins.bool
    iops: builtins.int
    snapshot_id: builtins.str
    volume_size: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delete_on_termination: builtins.bool = ...,
        iops: builtins.int = ...,
        snapshot_id: builtins.str = ...,
        volume_size: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_on_termination", b"delete_on_termination", "iops", b"iops", "resource_info", b"resource_info", "snapshot_id", b"snapshot_id", "volume_size", b"volume_size", "volume_type", b"volume_type"]) -> None: ...

global___InstanceEbsBlockDevice = InstanceEbsBlockDevice

@typing_extensions.final
class InstanceBlockDeviceMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    EBS_FIELD_NUMBER: builtins.int
    NO_DEVICE_FIELD_NUMBER: builtins.int
    VIRTUAL_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    device_name: builtins.str
    @property
    def ebs(self) -> global___InstanceEbsBlockDevice: ...
    no_device: builtins.str
    virtual_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        device_name: builtins.str = ...,
        ebs: global___InstanceEbsBlockDevice | None = ...,
        no_device: builtins.str = ...,
        virtual_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ebs", b"ebs", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_name", b"device_name", "ebs", b"ebs", "no_device", b"no_device", "resource_info", b"resource_info", "virtual_name", b"virtual_name"]) -> None: ...

global___InstanceBlockDeviceMapping = InstanceBlockDeviceMapping

@typing_extensions.final
class InstanceTimeBasedAutoScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class FridayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MondayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class SaturdayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class SundayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ThursdayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TuesdayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class WednesdayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FRIDAY_FIELD_NUMBER: builtins.int
    MONDAY_FIELD_NUMBER: builtins.int
    SATURDAY_FIELD_NUMBER: builtins.int
    SUNDAY_FIELD_NUMBER: builtins.int
    THURSDAY_FIELD_NUMBER: builtins.int
    TUESDAY_FIELD_NUMBER: builtins.int
    WEDNESDAY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def friday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def monday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def saturday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sunday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def thursday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tuesday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def wednesday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        friday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        monday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        saturday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sunday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        thursday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tuesday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        wednesday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["friday", b"friday", "monday", b"monday", "resource_info", b"resource_info", "saturday", b"saturday", "sunday", b"sunday", "thursday", b"thursday", "tuesday", b"tuesday", "wednesday", b"wednesday"]) -> None: ...

global___InstanceTimeBasedAutoScaling = InstanceTimeBasedAutoScaling

@typing_extensions.final
class Instance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AGENT_VERSION_FIELD_NUMBER: builtins.int
    AMI_ID_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    AUTO_SCALING_TYPE_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    BLOCK_DEVICE_MAPPINGS_FIELD_NUMBER: builtins.int
    EBS_OPTIMIZED_FIELD_NUMBER: builtins.int
    ELASTIC_IPS_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    INSTALL_UPDATES_ON_BOOT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    LAYER_IDS_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    ROOT_DEVICE_TYPE_FIELD_NUMBER: builtins.int
    SSH_KEY_NAME_FIELD_NUMBER: builtins.int
    STACK_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    TENANCY_FIELD_NUMBER: builtins.int
    TIME_BASED_AUTO_SCALING_FIELD_NUMBER: builtins.int
    VIRTUALIZATION_TYPE_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    agent_version: builtins.str
    ami_id: builtins.str
    architecture: builtins.str
    auto_scaling_type: builtins.str
    availability_zone: builtins.str
    @property
    def block_device_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceBlockDeviceMapping]: ...
    ebs_optimized: builtins.bool
    @property
    def elastic_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    hostname: builtins.str
    install_updates_on_boot: builtins.bool
    instance_type: builtins.str
    @property
    def layer_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    os: builtins.str
    root_device_type: builtins.str
    ssh_key_name: builtins.str
    stack_id: builtins.str
    subnet_id: builtins.str
    tenancy: builtins.str
    @property
    def time_based_auto_scaling(self) -> global___InstanceTimeBasedAutoScaling: ...
    virtualization_type: builtins.str
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        agent_version: builtins.str = ...,
        ami_id: builtins.str = ...,
        architecture: builtins.str = ...,
        auto_scaling_type: builtins.str = ...,
        availability_zone: builtins.str = ...,
        block_device_mappings: collections.abc.Iterable[global___InstanceBlockDeviceMapping] | None = ...,
        ebs_optimized: builtins.bool = ...,
        elastic_ips: collections.abc.Iterable[builtins.str] | None = ...,
        hostname: builtins.str = ...,
        install_updates_on_boot: builtins.bool = ...,
        instance_type: builtins.str = ...,
        layer_ids: collections.abc.Iterable[builtins.str] | None = ...,
        os: builtins.str = ...,
        root_device_type: builtins.str = ...,
        ssh_key_name: builtins.str = ...,
        stack_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        tenancy: builtins.str = ...,
        time_based_auto_scaling: global___InstanceTimeBasedAutoScaling | None = ...,
        virtualization_type: builtins.str = ...,
        volumes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "time_based_auto_scaling", b"time_based_auto_scaling"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_version", b"agent_version", "ami_id", b"ami_id", "architecture", b"architecture", "auto_scaling_type", b"auto_scaling_type", "availability_zone", b"availability_zone", "block_device_mappings", b"block_device_mappings", "ebs_optimized", b"ebs_optimized", "elastic_ips", b"elastic_ips", "hostname", b"hostname", "install_updates_on_boot", b"install_updates_on_boot", "instance_type", b"instance_type", "layer_ids", b"layer_ids", "os", b"os", "resource_info", b"resource_info", "root_device_type", b"root_device_type", "ssh_key_name", b"ssh_key_name", "stack_id", b"stack_id", "subnet_id", b"subnet_id", "tenancy", b"tenancy", "time_based_auto_scaling", b"time_based_auto_scaling", "virtualization_type", b"virtualization_type", "volumes", b"volumes"]) -> None: ...

global___Instance = Instance

@typing_extensions.final
class LayerRecipes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIGURE_FIELD_NUMBER: builtins.int
    DEPLOY_FIELD_NUMBER: builtins.int
    SETUP_FIELD_NUMBER: builtins.int
    SHUTDOWN_FIELD_NUMBER: builtins.int
    UNDEPLOY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def configure(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def deploy(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def setup(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def shutdown(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def undeploy(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        configure: collections.abc.Iterable[builtins.str] | None = ...,
        deploy: collections.abc.Iterable[builtins.str] | None = ...,
        setup: collections.abc.Iterable[builtins.str] | None = ...,
        shutdown: collections.abc.Iterable[builtins.str] | None = ...,
        undeploy: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configure", b"configure", "deploy", b"deploy", "resource_info", b"resource_info", "setup", b"setup", "shutdown", b"shutdown", "undeploy", b"undeploy"]) -> None: ...

global___LayerRecipes = LayerRecipes

@typing_extensions.final
class LayerShutdownEventConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELAY_UNTIL_ELB_CONNECTIONS_DRAINED_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delay_until_elb_connections_drained: builtins.bool
    execution_timeout: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delay_until_elb_connections_drained: builtins.bool = ...,
        execution_timeout: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delay_until_elb_connections_drained", b"delay_until_elb_connections_drained", "execution_timeout", b"execution_timeout", "resource_info", b"resource_info"]) -> None: ...

global___LayerShutdownEventConfiguration = LayerShutdownEventConfiguration

@typing_extensions.final
class LayerLifecycleEventConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SHUTDOWN_EVENT_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def shutdown_event_configuration(self) -> global___LayerShutdownEventConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        shutdown_event_configuration: global___LayerShutdownEventConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "shutdown_event_configuration", b"shutdown_event_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "shutdown_event_configuration", b"shutdown_event_configuration"]) -> None: ...

global___LayerLifecycleEventConfiguration = LayerLifecycleEventConfiguration

@typing_extensions.final
class LayerAutoScalingThresholds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CPU_THRESHOLD_FIELD_NUMBER: builtins.int
    IGNORE_METRICS_TIME_FIELD_NUMBER: builtins.int
    INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    LOAD_THRESHOLD_FIELD_NUMBER: builtins.int
    MEMORY_THRESHOLD_FIELD_NUMBER: builtins.int
    THRESHOLDS_WAIT_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cpu_threshold: builtins.float
    ignore_metrics_time: builtins.int
    instance_count: builtins.int
    load_threshold: builtins.float
    memory_threshold: builtins.float
    thresholds_wait_time: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cpu_threshold: builtins.float = ...,
        ignore_metrics_time: builtins.int = ...,
        instance_count: builtins.int = ...,
        load_threshold: builtins.float = ...,
        memory_threshold: builtins.float = ...,
        thresholds_wait_time: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_threshold", b"cpu_threshold", "ignore_metrics_time", b"ignore_metrics_time", "instance_count", b"instance_count", "load_threshold", b"load_threshold", "memory_threshold", b"memory_threshold", "resource_info", b"resource_info", "thresholds_wait_time", b"thresholds_wait_time"]) -> None: ...

global___LayerAutoScalingThresholds = LayerAutoScalingThresholds

@typing_extensions.final
class LayerLoadBasedAutoScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOWN_SCALING_FIELD_NUMBER: builtins.int
    ENABLE_FIELD_NUMBER: builtins.int
    UP_SCALING_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def down_scaling(self) -> global___LayerAutoScalingThresholds: ...
    enable: builtins.bool
    @property
    def up_scaling(self) -> global___LayerAutoScalingThresholds: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        down_scaling: global___LayerAutoScalingThresholds | None = ...,
        enable: builtins.bool = ...,
        up_scaling: global___LayerAutoScalingThresholds | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["down_scaling", b"down_scaling", "resource_info", b"resource_info", "up_scaling", b"up_scaling"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["down_scaling", b"down_scaling", "enable", b"enable", "resource_info", b"resource_info", "up_scaling", b"up_scaling"]) -> None: ...

global___LayerLoadBasedAutoScaling = LayerLoadBasedAutoScaling

@typing_extensions.final
class LayerVolumeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    MOUNT_POINT_FIELD_NUMBER: builtins.int
    NUMBER_OF_DISKS_FIELD_NUMBER: builtins.int
    RAID_LEVEL_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    encrypted: builtins.bool
    iops: builtins.int
    mount_point: builtins.str
    number_of_disks: builtins.int
    raid_level: builtins.int
    size: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encrypted: builtins.bool = ...,
        iops: builtins.int = ...,
        mount_point: builtins.str = ...,
        number_of_disks: builtins.int = ...,
        raid_level: builtins.int = ...,
        size: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encrypted", b"encrypted", "iops", b"iops", "mount_point", b"mount_point", "number_of_disks", b"number_of_disks", "raid_level", b"raid_level", "resource_info", b"resource_info", "size", b"size", "volume_type", b"volume_type"]) -> None: ...

global___LayerVolumeConfiguration = LayerVolumeConfiguration

@typing_extensions.final
class Layer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class CustomJsonEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    AUTO_ASSIGN_ELASTIC_IPS_FIELD_NUMBER: builtins.int
    AUTO_ASSIGN_PUBLIC_IPS_FIELD_NUMBER: builtins.int
    CUSTOM_INSTANCE_PROFILE_ARN_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    CUSTOM_RECIPES_FIELD_NUMBER: builtins.int
    CUSTOM_SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_HEALING_FIELD_NUMBER: builtins.int
    INSTALL_UPDATES_ON_BOOT_FIELD_NUMBER: builtins.int
    LIFECYCLE_EVENT_CONFIGURATION_FIELD_NUMBER: builtins.int
    LOAD_BASED_AUTO_SCALING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PACKAGES_FIELD_NUMBER: builtins.int
    SHORTNAME_FIELD_NUMBER: builtins.int
    STACK_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USE_EBS_OPTIMIZED_INSTANCES_FIELD_NUMBER: builtins.int
    VOLUME_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    auto_assign_elastic_ips: builtins.bool
    auto_assign_public_ips: builtins.bool
    custom_instance_profile_arn: builtins.str
    @property
    def custom_json(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def custom_recipes(self) -> global___LayerRecipes: ...
    @property
    def custom_security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_auto_healing: builtins.bool
    install_updates_on_boot: builtins.bool
    @property
    def lifecycle_event_configuration(self) -> global___LayerLifecycleEventConfiguration: ...
    @property
    def load_based_auto_scaling(self) -> global___LayerLoadBasedAutoScaling: ...
    name: builtins.str
    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    shortname: builtins.str
    stack_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    use_ebs_optimized_instances: builtins.bool
    @property
    def volume_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LayerVolumeConfiguration]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        auto_assign_elastic_ips: builtins.bool = ...,
        auto_assign_public_ips: builtins.bool = ...,
        custom_instance_profile_arn: builtins.str = ...,
        custom_json: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        custom_recipes: global___LayerRecipes | None = ...,
        custom_security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        enable_auto_healing: builtins.bool = ...,
        install_updates_on_boot: builtins.bool = ...,
        lifecycle_event_configuration: global___LayerLifecycleEventConfiguration | None = ...,
        load_based_auto_scaling: global___LayerLoadBasedAutoScaling | None = ...,
        name: builtins.str = ...,
        packages: collections.abc.Iterable[builtins.str] | None = ...,
        shortname: builtins.str = ...,
        stack_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        use_ebs_optimized_instances: builtins.bool = ...,
        volume_configurations: collections.abc.Iterable[global___LayerVolumeConfiguration] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_recipes", b"custom_recipes", "lifecycle_event_configuration", b"lifecycle_event_configuration", "load_based_auto_scaling", b"load_based_auto_scaling", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "auto_assign_elastic_ips", b"auto_assign_elastic_ips", "auto_assign_public_ips", b"auto_assign_public_ips", "custom_instance_profile_arn", b"custom_instance_profile_arn", "custom_json", b"custom_json", "custom_recipes", b"custom_recipes", "custom_security_group_ids", b"custom_security_group_ids", "enable_auto_healing", b"enable_auto_healing", "install_updates_on_boot", b"install_updates_on_boot", "lifecycle_event_configuration", b"lifecycle_event_configuration", "load_based_auto_scaling", b"load_based_auto_scaling", "name", b"name", "packages", b"packages", "resource_info", b"resource_info", "shortname", b"shortname", "stack_id", b"stack_id", "tags", b"tags", "type", b"type", "use_ebs_optimized_instances", b"use_ebs_optimized_instances", "volume_configurations", b"volume_configurations"]) -> None: ...

global___Layer = Layer

@typing_extensions.final
class StackChefConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BERKSHELF_VERSION_FIELD_NUMBER: builtins.int
    MANAGE_BERKSHELF_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    berkshelf_version: builtins.str
    manage_berkshelf: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        berkshelf_version: builtins.str = ...,
        manage_berkshelf: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["berkshelf_version", b"berkshelf_version", "manage_berkshelf", b"manage_berkshelf", "resource_info", b"resource_info"]) -> None: ...

global___StackChefConfiguration = StackChefConfiguration

@typing_extensions.final
class StackStackConfigurationManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___StackStackConfigurationManager = StackStackConfigurationManager

@typing_extensions.final
class StackSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    SSH_KEY_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    password: builtins.str
    revision: builtins.str
    ssh_key: builtins.str
    url: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        password: builtins.str = ...,
        revision: builtins.str = ...,
        ssh_key: builtins.str = ...,
        url: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "revision", b"revision", "ssh_key", b"ssh_key", "url", b"url", "username", b"username"]) -> None: ...

global___StackSource = StackSource

@typing_extensions.final
class StackElasticIp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ip: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ip: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip", b"ip", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___StackElasticIp = StackElasticIp

@typing_extensions.final
class StackRdsDbInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DB_PASSWORD_FIELD_NUMBER: builtins.int
    DB_USER_FIELD_NUMBER: builtins.int
    RDS_DB_INSTANCE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    db_password: builtins.str
    db_user: builtins.str
    rds_db_instance_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        db_password: builtins.str = ...,
        db_user: builtins.str = ...,
        rds_db_instance_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["db_password", b"db_password", "db_user", b"db_user", "rds_db_instance_arn", b"rds_db_instance_arn", "resource_info", b"resource_info"]) -> None: ...

global___StackRdsDbInstance = StackRdsDbInstance

@typing_extensions.final
class Stack(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class CustomJsonEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AGENT_VERSION_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    CHEF_CONFIGURATION_FIELD_NUMBER: builtins.int
    CLONE_APP_IDS_FIELD_NUMBER: builtins.int
    CLONE_PERMISSIONS_FIELD_NUMBER: builtins.int
    CONFIGURATION_MANAGER_FIELD_NUMBER: builtins.int
    CUSTOM_COOKBOOKS_SOURCE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    DEFAULT_AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    DEFAULT_INSTANCE_PROFILE_ARN_FIELD_NUMBER: builtins.int
    DEFAULT_OS_FIELD_NUMBER: builtins.int
    DEFAULT_ROOT_DEVICE_TYPE_FIELD_NUMBER: builtins.int
    DEFAULT_SSH_KEY_NAME_FIELD_NUMBER: builtins.int
    DEFAULT_SUBNET_ID_FIELD_NUMBER: builtins.int
    ECS_CLUSTER_ARN_FIELD_NUMBER: builtins.int
    ELASTIC_IPS_FIELD_NUMBER: builtins.int
    HOSTNAME_THEME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RDS_DB_INSTANCES_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    SOURCE_STACK_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    USE_CUSTOM_COOKBOOKS_FIELD_NUMBER: builtins.int
    USE_OPSWORKS_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    agent_version: builtins.str
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def chef_configuration(self) -> global___StackChefConfiguration: ...
    @property
    def clone_app_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    clone_permissions: builtins.bool
    @property
    def configuration_manager(self) -> global___StackStackConfigurationManager: ...
    @property
    def custom_cookbooks_source(self) -> global___StackSource: ...
    @property
    def custom_json(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    default_availability_zone: builtins.str
    default_instance_profile_arn: builtins.str
    default_os: builtins.str
    default_root_device_type: builtins.str
    default_ssh_key_name: builtins.str
    default_subnet_id: builtins.str
    ecs_cluster_arn: builtins.str
    @property
    def elastic_ips(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StackElasticIp]: ...
    hostname_theme: builtins.str
    name: builtins.str
    @property
    def rds_db_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StackRdsDbInstance]: ...
    service_role_arn: builtins.str
    source_stack_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    use_custom_cookbooks: builtins.bool
    use_opsworks_security_groups: builtins.bool
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        agent_version: builtins.str = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        chef_configuration: global___StackChefConfiguration | None = ...,
        clone_app_ids: collections.abc.Iterable[builtins.str] | None = ...,
        clone_permissions: builtins.bool = ...,
        configuration_manager: global___StackStackConfigurationManager | None = ...,
        custom_cookbooks_source: global___StackSource | None = ...,
        custom_json: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_availability_zone: builtins.str = ...,
        default_instance_profile_arn: builtins.str = ...,
        default_os: builtins.str = ...,
        default_root_device_type: builtins.str = ...,
        default_ssh_key_name: builtins.str = ...,
        default_subnet_id: builtins.str = ...,
        ecs_cluster_arn: builtins.str = ...,
        elastic_ips: collections.abc.Iterable[global___StackElasticIp] | None = ...,
        hostname_theme: builtins.str = ...,
        name: builtins.str = ...,
        rds_db_instances: collections.abc.Iterable[global___StackRdsDbInstance] | None = ...,
        service_role_arn: builtins.str = ...,
        source_stack_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        use_custom_cookbooks: builtins.bool = ...,
        use_opsworks_security_groups: builtins.bool = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chef_configuration", b"chef_configuration", "configuration_manager", b"configuration_manager", "custom_cookbooks_source", b"custom_cookbooks_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_version", b"agent_version", "attributes", b"attributes", "chef_configuration", b"chef_configuration", "clone_app_ids", b"clone_app_ids", "clone_permissions", b"clone_permissions", "configuration_manager", b"configuration_manager", "custom_cookbooks_source", b"custom_cookbooks_source", "custom_json", b"custom_json", "default_availability_zone", b"default_availability_zone", "default_instance_profile_arn", b"default_instance_profile_arn", "default_os", b"default_os", "default_root_device_type", b"default_root_device_type", "default_ssh_key_name", b"default_ssh_key_name", "default_subnet_id", b"default_subnet_id", "ecs_cluster_arn", b"ecs_cluster_arn", "elastic_ips", b"elastic_ips", "hostname_theme", b"hostname_theme", "name", b"name", "rds_db_instances", b"rds_db_instances", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "source_stack_id", b"source_stack_id", "tags", b"tags", "use_custom_cookbooks", b"use_custom_cookbooks", "use_opsworks_security_groups", b"use_opsworks_security_groups", "vpc_id", b"vpc_id"]) -> None: ...

global___Stack = Stack

@typing_extensions.final
class UserProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOW_SELF_MANAGEMENT_FIELD_NUMBER: builtins.int
    IAM_USER_ARN_FIELD_NUMBER: builtins.int
    SSH_PUBLIC_KEY_FIELD_NUMBER: builtins.int
    SSH_USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    allow_self_management: builtins.bool
    iam_user_arn: builtins.str
    ssh_public_key: builtins.str
    ssh_username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allow_self_management: builtins.bool = ...,
        iam_user_arn: builtins.str = ...,
        ssh_public_key: builtins.str = ...,
        ssh_username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_self_management", b"allow_self_management", "iam_user_arn", b"iam_user_arn", "resource_info", b"resource_info", "ssh_public_key", b"ssh_public_key", "ssh_username", b"ssh_username"]) -> None: ...

global___UserProfile = UserProfile

@typing_extensions.final
class Volume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EC2_VOLUME_ID_FIELD_NUMBER: builtins.int
    MOUNT_POINT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STACK_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ec2_volume_id: builtins.str
    mount_point: builtins.str
    name: builtins.str
    stack_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ec2_volume_id: builtins.str = ...,
        mount_point: builtins.str = ...,
        name: builtins.str = ...,
        stack_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_volume_id", b"ec2_volume_id", "mount_point", b"mount_point", "name", b"name", "resource_info", b"resource_info", "stack_id", b"stack_id"]) -> None: ...

global___Volume = Volume



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_guardduty.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_guardduty.proto\x12\x19oak9.tython.aws.guardduty\x1a\x13shared/shared.proto\"i\n\x1e\x44\x65tectorCFNS3LogsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\"\xaa\x01\n#DetectorCFNDataSourceConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x07s3_logs\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.guardduty.DetectorCFNS3LogsConfiguration\"\xcf\x01\n\x08\x44\x65tector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12$\n\x1c\x66inding_publishing_frequency\x18\x02 \x01(\t\x12T\n\x0c\x64\x61ta_sources\x18\x03 \x01(\x0b\x32>.oak9.tython.aws.guardduty.DetectorCFNDataSourceConfigurations\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\"\xd2\x02\n\tGuardDuty\x12\x35\n\x08\x64\x65tector\x18\x01 \x03(\x0b\x32#.oak9.tython.aws.guardduty.Detector\x12\x31\n\x06\x66ilter\x18\x02 \x03(\x0b\x32!.oak9.tython.aws.guardduty.Filter\x12\x30\n\x06ip_set\x18\x03 \x03(\x0b\x32 .oak9.tython.aws.guardduty.IPSet\x12\x31\n\x06master\x18\x04 \x03(\x0b\x32!.oak9.tython.aws.guardduty.Master\x12\x31\n\x06member\x18\x05 \x03(\x0b\x32!.oak9.tython.aws.guardduty.Member\x12\x43\n\x10threat_intel_set\x18\x06 \x03(\x0b\x32).oak9.tython.aws.guardduty.ThreatIntelSet\"\x89\x01\n\x0f\x46ilterCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02lt\x18\x02 \x01(\x05\x12\x0b\n\x03gte\x18\x03 \x01(\x05\x12\x0b\n\x03neq\x18\x04 \x03(\t\x12\n\n\x02\x65q\x18\x05 \x03(\t\x12\x0b\n\x03lte\x18\x06 \x01(\x05\"\x95\x02\n\x15\x46ilterFindingCriteria\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\tcriterion\x18\x02 \x03(\x0b\x32?.oak9.tython.aws.guardduty.FilterFindingCriteria.CriterionEntry\x12=\n\titem_type\x18\x03 \x01(\x0b\x32*.oak9.tython.aws.guardduty.FilterCondition\x1a\x30\n\x0e\x43riterionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe3\x01\n\x06\x46ilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65tector_id\x18\x04 \x01(\t\x12J\n\x10\x66inding_criteria\x18\x05 \x01(\x0b\x32\x30.oak9.tython.aws.guardduty.FilterFindingCriteria\x12\x0c\n\x04rank\x18\x06 \x01(\x05\x12\x0c\n\x04name\x18\x07 \x01(\t\"\x97\x01\n\x05IPSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x10\n\x08\x61\x63tivate\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65tector_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\"\x80\x01\n\x06Master\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65tector_id\x18\x02 \x01(\t\x12\x11\n\tmaster_id\x18\x03 \x01(\t\x12\x15\n\rinvitation_id\x18\x04 \x01(\t\"\xbd\x01\n\x06Member\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\"\n\x1a\x64isable_email_notification\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65tector_id\x18\x07 \x01(\t\"\xa0\x01\n\x0eThreatIntelSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x10\n\x08\x61\x63tivate\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65tector_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_guardduty_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FILTERFINDINGCRITERIA_CRITERIONENTRY._options = None
  _FILTERFINDINGCRITERIA_CRITERIONENTRY._serialized_options = b'8\001'
  _DETECTORCFNS3LOGSCONFIGURATION._serialized_start=75
  _DETECTORCFNS3LOGSCONFIGURATION._serialized_end=180
  _DETECTORCFNDATASOURCECONFIGURATIONS._serialized_start=183
  _DETECTORCFNDATASOURCECONFIGURATIONS._serialized_end=353
  _DETECTOR._serialized_start=356
  _DETECTOR._serialized_end=563
  _GUARDDUTY._serialized_start=566
  _GUARDDUTY._serialized_end=904
  _FILTERCONDITION._serialized_start=907
  _FILTERCONDITION._serialized_end=1044
  _FILTERFINDINGCRITERIA._serialized_start=1047
  _FILTERFINDINGCRITERIA._serialized_end=1324
  _FILTERFINDINGCRITERIA_CRITERIONENTRY._serialized_start=1276
  _FILTERFINDINGCRITERIA_CRITERIONENTRY._serialized_end=1324
  _FILTER._serialized_start=1327
  _FILTER._serialized_end=1554
  _IPSET._serialized_start=1557
  _IPSET._serialized_end=1708
  _MASTER._serialized_start=1711
  _MASTER._serialized_end=1839
  _MEMBER._serialized_start=1842
  _MEMBER._serialized_end=2031
  _THREATINTELSET._serialized_start=2034
  _THREATINTELSET._serialized_end=2194
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_app.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61zure/azure_microsoft_app.proto\x12\x1foak9.tython.azure.microsoft_app\x1a\x13shared/shared.proto\"\xbb\x01\n\rMicrosoft_App\x12V\n\x16\x63onnected_environments\x18\x01 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_app.ConnectedEnvironments\x12R\n\x14managed_environments\x18\x02 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_app.ManagedEnvironments\"\xae\x01\n\x1bManagedEnvironmentsStorages\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\nazure_file\x18\x03 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app.AzureFileProperties\"\xeb\x02\n!ManagedEnvironmentsDaprComponents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x63omponent_type\x18\x03 \x01(\t\x12\x15\n\rignore_errors\x18\x04 \x01(\x08\x12\x14\n\x0cinit_timeout\x18\x05 \x01(\t\x12?\n\x08metadata\x18\x06 \x03(\x0b\x32-.oak9.tython.azure.microsoft_app.DaprMetadata\x12\x0e\n\x06scopes\x18\x07 \x03(\t\x12\x38\n\x07secrets\x18\x08 \x03(\x0b\x32\'.oak9.tython.azure.microsoft_app.Secret\x12\x1e\n\x16secret_store_component\x18\t \x01(\t\x12\x0f\n\x07version\x18\n \x01(\t\"\xa2\x02\n\x1fManagedEnvironmentsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12X\n\x04tags\x18\x06 \x03(\x0b\x32J.oak9.tython.azure.microsoft_app.ManagedEnvironmentsCertificates.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x08\n\x13ManagedEnvironments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12U\n\x16\x61pp_logs_configuration\x18\x04 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_app.AppLogsConfiguration\x12_\n\x1b\x63ustom_domain_configuration\x18\x05 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app.CustomDomainConfiguration\x12\"\n\x1a\x64\x61pr_a_i_connection_string\x18\x06 \x01(\t\x12$\n\x1c\x64\x61pr_a_i_instrumentation_key\x18\x07 \x01(\t\x12N\n\x12vnet_configuration\x18\x08 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_app.VnetConfiguration\x12K\n\x11workload_profiles\x18\t \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_app.WorkloadProfile\x12\x16\n\x0ezone_redundant\x18\n \x01(\x08\x12\x46\n\x03sku\x18\x0b \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_app.EnvironmentSkuProperties\x12L\n\x04tags\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_app.ManagedEnvironments.TagsEntry\x12p\n$managed_environments_dapr_components\x18\r \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_app.ManagedEnvironmentsDaprComponents\x12k\n!managed_environments_certificates\x18\x0e \x03(\x0b\x32@.oak9.tython.azure.microsoft_app.ManagedEnvironmentsCertificates\x12\x63\n\x1dmanaged_environments_storages\x18\x0f \x03(\x0b\x32<.oak9.tython.azure.microsoft_app.ManagedEnvironmentsStorages\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"(\n\x18\x45nvironmentSkuProperties\x12\x0c\n\x04name\x18\x01 \x01(\t\"^\n\x0fWorkloadProfile\x12\x15\n\rmaximum_count\x18\x01 \x01(\x05\x12\x15\n\rminimum_count\x18\x02 \x01(\x05\x12\x1d\n\x15workload_profile_type\x18\x03 \x01(\t\"\xa0\x02\n\x11VnetConfiguration\x12\x1a\n\x12\x64ocker_bridge_cidr\x18\x01 \x01(\t\x12 \n\x18infrastructure_subnet_id\x18\x02 \x01(\t\x12\x10\n\x08internal\x18\x03 \x01(\x08\x12^\n\x11outbound_settings\x18\x04 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_app.ManagedEnvironmentOutboundSettings\x12\x1e\n\x16platform_reserved_cidr\x18\x05 \x01(\t\x12 \n\x18platform_reserved_dns_ip\x18\x06 \x01(\t\x12\x19\n\x11runtime_subnet_id\x18\x07 \x01(\t\"b\n\"ManagedEnvironmentOutboundSettings\x12\x16\n\x0eout_bound_type\x18\x01 \x01(\t\x12$\n\x1cvirtual_network_appliance_ip\x18\x02 \x01(\t\"\x8c\x01\n\x14\x41ppLogsConfiguration\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12_\n\x1blog_analytics_configuration\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app.LogAnalyticsConfiguration\"D\n\x19LogAnalyticsConfiguration\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x12\n\nshared_key\x18\x02 \x01(\t\"\xb0\x01\n\x1d\x43onnectedEnvironmentsStorages\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\nazure_file\x18\x03 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app.AzureFileProperties\"i\n\x13\x41zureFileProperties\x12\x13\n\x0b\x61\x63\x63\x65ss_mode\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x03 \x01(\t\x12\x12\n\nshare_name\x18\x04 \x01(\t\"\xed\x02\n#ConnectedEnvironmentsDaprComponents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x63omponent_type\x18\x03 \x01(\t\x12\x15\n\rignore_errors\x18\x04 \x01(\x08\x12\x14\n\x0cinit_timeout\x18\x05 \x01(\t\x12?\n\x08metadata\x18\x06 \x03(\x0b\x32-.oak9.tython.azure.microsoft_app.DaprMetadata\x12\x0e\n\x06scopes\x18\x07 \x03(\t\x12\x38\n\x07secrets\x18\x08 \x03(\x0b\x32\'.oak9.tython.azure.microsoft_app.Secret\x12\x1e\n\x16secret_store_component\x18\t \x01(\t\x12\x0f\n\x07version\x18\n \x01(\t\"%\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"?\n\x0c\x44\x61prMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nsecret_ref\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa6\x02\n!ConnectedEnvironmentsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12Z\n\x04tags\x18\x06 \x03(\x0b\x32L.oak9.tython.azure.microsoft_app.ConnectedEnvironmentsCertificates.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x06\n\x15\x43onnectedEnvironments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_app.ExtendedLocation\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12_\n\x1b\x63ustom_domain_configuration\x18\x05 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app.CustomDomainConfiguration\x12\"\n\x1a\x64\x61pr_a_i_connection_string\x18\x06 \x01(\t\x12\x11\n\tstatic_ip\x18\x07 \x01(\t\x12N\n\x04tags\x18\x08 \x03(\x0b\x32@.oak9.tython.azure.microsoft_app.ConnectedEnvironments.TagsEntry\x12o\n#connected_environments_certificates\x18\t \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_app.ConnectedEnvironmentsCertificates\x12t\n&connected_environments_dapr_components\x18\n \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_app.ConnectedEnvironmentsDaprComponents\x12g\n\x1f\x63onnected_environments_storages\x18\x0b \x03(\x0b\x32>.oak9.tython.azure.microsoft_app.ConnectedEnvironmentsStorages\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x19\x43ustomDomainConfiguration\x12\x1c\n\x14\x63\x65rtificate_password\x18\x01 \x01(\t\x12\x19\n\x11\x63\x65rtificate_value\x18\x02 \x01(\t\x12\x12\n\ndns_suffix\x18\x03 \x01(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_app_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MANAGEDENVIRONMENTSCERTIFICATES_TAGSENTRY._options = None
  _MANAGEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDENVIRONMENTS_TAGSENTRY._options = None
  _MANAGEDENVIRONMENTS_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTEDENVIRONMENTSCERTIFICATES_TAGSENTRY._options = None
  _CONNECTEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTEDENVIRONMENTS_TAGSENTRY._options = None
  _CONNECTEDENVIRONMENTS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_APP._serialized_start=90
  _MICROSOFT_APP._serialized_end=277
  _MANAGEDENVIRONMENTSSTORAGES._serialized_start=280
  _MANAGEDENVIRONMENTSSTORAGES._serialized_end=454
  _MANAGEDENVIRONMENTSDAPRCOMPONENTS._serialized_start=457
  _MANAGEDENVIRONMENTSDAPRCOMPONENTS._serialized_end=820
  _MANAGEDENVIRONMENTSCERTIFICATES._serialized_start=823
  _MANAGEDENVIRONMENTSCERTIFICATES._serialized_end=1113
  _MANAGEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_start=1070
  _MANAGEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_end=1113
  _MANAGEDENVIRONMENTS._serialized_start=1116
  _MANAGEDENVIRONMENTS._serialized_end=2184
  _MANAGEDENVIRONMENTS_TAGSENTRY._serialized_start=1070
  _MANAGEDENVIRONMENTS_TAGSENTRY._serialized_end=1113
  _ENVIRONMENTSKUPROPERTIES._serialized_start=2186
  _ENVIRONMENTSKUPROPERTIES._serialized_end=2226
  _WORKLOADPROFILE._serialized_start=2228
  _WORKLOADPROFILE._serialized_end=2322
  _VNETCONFIGURATION._serialized_start=2325
  _VNETCONFIGURATION._serialized_end=2613
  _MANAGEDENVIRONMENTOUTBOUNDSETTINGS._serialized_start=2615
  _MANAGEDENVIRONMENTOUTBOUNDSETTINGS._serialized_end=2713
  _APPLOGSCONFIGURATION._serialized_start=2716
  _APPLOGSCONFIGURATION._serialized_end=2856
  _LOGANALYTICSCONFIGURATION._serialized_start=2858
  _LOGANALYTICSCONFIGURATION._serialized_end=2926
  _CONNECTEDENVIRONMENTSSTORAGES._serialized_start=2929
  _CONNECTEDENVIRONMENTSSTORAGES._serialized_end=3105
  _AZUREFILEPROPERTIES._serialized_start=3107
  _AZUREFILEPROPERTIES._serialized_end=3212
  _CONNECTEDENVIRONMENTSDAPRCOMPONENTS._serialized_start=3215
  _CONNECTEDENVIRONMENTSDAPRCOMPONENTS._serialized_end=3580
  _SECRET._serialized_start=3582
  _SECRET._serialized_end=3619
  _DAPRMETADATA._serialized_start=3621
  _DAPRMETADATA._serialized_end=3684
  _CONNECTEDENVIRONMENTSCERTIFICATES._serialized_start=3687
  _CONNECTEDENVIRONMENTSCERTIFICATES._serialized_end=3981
  _CONNECTEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_start=1070
  _CONNECTEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_end=1113
  _CONNECTEDENVIRONMENTS._serialized_start=3984
  _CONNECTEDENVIRONMENTS._serialized_end=4787
  _CONNECTEDENVIRONMENTS_TAGSENTRY._serialized_start=1070
  _CONNECTEDENVIRONMENTS_TAGSENTRY._serialized_end=1113
  _CUSTOMDOMAINCONFIGURATION._serialized_start=4789
  _CUSTOMDOMAINCONFIGURATION._serialized_end=4893
  _EXTENDEDLOCATION._serialized_start=4895
  _EXTENDEDLOCATION._serialized_end=4941
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_storage_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleStorage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_BUCKET_FIELD_NUMBER: builtins.int
    STORAGE_BUCKET_ACCESS_CONTROL_FIELD_NUMBER: builtins.int
    STORAGE_BUCKET_ACL_FIELD_NUMBER: builtins.int
    STORAGE_BUCKET_IAM_BINDING_FIELD_NUMBER: builtins.int
    STORAGE_BUCKET_IAM_MEMBER_FIELD_NUMBER: builtins.int
    STORAGE_BUCKET_IAM_POLICY_FIELD_NUMBER: builtins.int
    STORAGE_BUCKET_OBJECT_FIELD_NUMBER: builtins.int
    STORAGE_DEFAULT_OBJECT_ACCESS_CONTROL_FIELD_NUMBER: builtins.int
    STORAGE_DEFAULT_OBJECT_ACL_FIELD_NUMBER: builtins.int
    STORAGE_HMAC_KEY_FIELD_NUMBER: builtins.int
    STORAGE_NOTIFICATION_FIELD_NUMBER: builtins.int
    STORAGE_OBJECT_ACCESS_CONTROL_FIELD_NUMBER: builtins.int
    STORAGE_OBJECT_ACL_FIELD_NUMBER: builtins.int
    STORAGE_TRANSFER_JOB_FIELD_NUMBER: builtins.int
    @property
    def storage_bucket(self) -> gcp.gcp_storage_pb2.StorageBucket: ...
    @property
    def storage_bucket_access_control(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_storage_pb2.StorageBucketAccessControl]: ...
    @property
    def storage_bucket_acl(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_storage_pb2.StorageBucketAcl]: ...
    @property
    def storage_bucket_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_storage_pb2.StorageBucketIamBinding]: ...
    @property
    def storage_bucket_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_storage_pb2.StorageBucketIamMember]: ...
    @property
    def storage_bucket_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_storage_pb2.StorageBucketIamPolicy]: ...
    @property
    def storage_bucket_object(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_storage_pb2.StorageBucketObject]: ...
    @property
    def storage_default_object_access_control(self) -> gcp.gcp_storage_pb2.StorageDefaultObjectAccessControl: ...
    @property
    def storage_default_object_acl(self) -> gcp.gcp_storage_pb2.StorageDefaultObjectAcl: ...
    @property
    def storage_hmac_key(self) -> gcp.gcp_storage_pb2.StorageHmacKey: ...
    @property
    def storage_notification(self) -> gcp.gcp_storage_pb2.StorageNotification: ...
    @property
    def storage_object_access_control(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_storage_pb2.StorageObjectAccessControl]: ...
    @property
    def storage_object_acl(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_storage_pb2.StorageObjectAcl]: ...
    @property
    def storage_transfer_job(self) -> gcp.gcp_storage_pb2.StorageTransferJob: ...
    def __init__(
        self,
        *,
        storage_bucket: gcp.gcp_storage_pb2.StorageBucket | None = ...,
        storage_bucket_access_control: collections.abc.Iterable[gcp.gcp_storage_pb2.StorageBucketAccessControl] | None = ...,
        storage_bucket_acl: collections.abc.Iterable[gcp.gcp_storage_pb2.StorageBucketAcl] | None = ...,
        storage_bucket_iam_binding: collections.abc.Iterable[gcp.gcp_storage_pb2.StorageBucketIamBinding] | None = ...,
        storage_bucket_iam_member: collections.abc.Iterable[gcp.gcp_storage_pb2.StorageBucketIamMember] | None = ...,
        storage_bucket_iam_policy: collections.abc.Iterable[gcp.gcp_storage_pb2.StorageBucketIamPolicy] | None = ...,
        storage_bucket_object: collections.abc.Iterable[gcp.gcp_storage_pb2.StorageBucketObject] | None = ...,
        storage_default_object_access_control: gcp.gcp_storage_pb2.StorageDefaultObjectAccessControl | None = ...,
        storage_default_object_acl: gcp.gcp_storage_pb2.StorageDefaultObjectAcl | None = ...,
        storage_hmac_key: gcp.gcp_storage_pb2.StorageHmacKey | None = ...,
        storage_notification: gcp.gcp_storage_pb2.StorageNotification | None = ...,
        storage_object_access_control: collections.abc.Iterable[gcp.gcp_storage_pb2.StorageObjectAccessControl] | None = ...,
        storage_object_acl: collections.abc.Iterable[gcp.gcp_storage_pb2.StorageObjectAcl] | None = ...,
        storage_transfer_job: gcp.gcp_storage_pb2.StorageTransferJob | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["storage_bucket", b"storage_bucket", "storage_default_object_access_control", b"storage_default_object_access_control", "storage_default_object_acl", b"storage_default_object_acl", "storage_hmac_key", b"storage_hmac_key", "storage_notification", b"storage_notification", "storage_transfer_job", b"storage_transfer_job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["storage_bucket", b"storage_bucket", "storage_bucket_access_control", b"storage_bucket_access_control", "storage_bucket_acl", b"storage_bucket_acl", "storage_bucket_iam_binding", b"storage_bucket_iam_binding", "storage_bucket_iam_member", b"storage_bucket_iam_member", "storage_bucket_iam_policy", b"storage_bucket_iam_policy", "storage_bucket_object", b"storage_bucket_object", "storage_default_object_access_control", b"storage_default_object_access_control", "storage_default_object_acl", b"storage_default_object_acl", "storage_hmac_key", b"storage_hmac_key", "storage_notification", b"storage_notification", "storage_object_access_control", b"storage_object_access_control", "storage_object_acl", b"storage_object_acl", "storage_transfer_job", b"storage_transfer_job"]) -> None: ...

global___GoogleStorage = GoogleStorage



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_directoryservice.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_directoryservice.proto\x12 oak9.tython.aws.directoryservice\x1a\x13shared/shared.proto\"u\n\x16MicrosoftADVpcSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nsubnet_ids\x18\x02 \x03(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\"\x85\x02\n\x0bMicrosoftAD\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63reate_alias\x18\x02 \x01(\x08\x12\x0f\n\x07\x65\x64ition\x18\x03 \x01(\t\x12\x12\n\nenable_sso\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08password\x18\x06 \x01(\t\x12\x12\n\nshort_name\x18\x07 \x01(\t\x12N\n\x0cvpc_settings\x18\x08 \x01(\x0b\x32\x38.oak9.tython.aws.directoryservice.MicrosoftADVpcSettings\"\x96\x01\n\x10\x44irectoryService\x12\x43\n\x0cmicrosoft_ad\x18\x01 \x03(\x0b\x32-.oak9.tython.aws.directoryservice.MicrosoftAD\x12=\n\tsimple_ad\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.directoryservice.SimpleAD\"r\n\x13SimpleADVpcSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nsubnet_ids\x18\x02 \x03(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\"\x91\x02\n\x08SimpleAD\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63reate_alias\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nenable_sso\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08password\x18\x06 \x01(\t\x12\x12\n\nshort_name\x18\x07 \x01(\t\x12\x0c\n\x04size\x18\x08 \x01(\t\x12K\n\x0cvpc_settings\x18\t \x01(\x0b\x32\x35.oak9.tython.aws.directoryservice.SimpleADVpcSettingsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_directoryservice_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MICROSOFTADVPCSETTINGS._serialized_start=89
  _MICROSOFTADVPCSETTINGS._serialized_end=206
  _MICROSOFTAD._serialized_start=209
  _MICROSOFTAD._serialized_end=470
  _DIRECTORYSERVICE._serialized_start=473
  _DIRECTORYSERVICE._serialized_end=623
  _SIMPLEADVPCSETTINGS._serialized_start=625
  _SIMPLEADVPCSETTINGS._serialized_end=739
  _SIMPLEAD._serialized_start=742
  _SIMPLEAD._serialized_end=1015
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_recoveryservices.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,azure/azure_microsoft_recoveryservices.proto\x12,oak9.tython.azure.microsoft_recoveryservices\x1a\x13shared/shared.proto\"b\n\x1aMicrosoft_RecoveryServices\x12\x44\n\x06vaults\x18\x01 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_recoveryservices.Vaults\"\xd5\x01\n\x19VaultsExtendedInformation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\talgorithm\x18\x04 \x01(\t\x12\x16\n\x0e\x65ncryption_key\x18\x05 \x01(\t\x12!\n\x19\x65ncryption_key_thumbprint\x18\x06 \x01(\t\x12\x15\n\rintegrity_key\x18\x07 \x01(\t\"\x83\x01\n\x12VaultsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tauth_type\x18\x03 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x04 \x01(\t\"\xa8\x07\n\x06Vaults\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12L\n\x08identity\x18\x03 \x01(\x0b\x32:.oak9.tython.azure.microsoft_recoveryservices.IdentityData\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12[\n\nencryption\x18\x06 \x01(\x0b\x32G.oak9.tython.azure.microsoft_recoveryservices.VaultPropertiesEncryption\x12^\n\x0cmove_details\x18\x07 \x01(\x0b\x32H.oak9.tython.azure.microsoft_recoveryservices.VaultPropertiesMoveDetails\x12U\n\x0fupgrade_details\x18\x08 \x01(\x0b\x32<.oak9.tython.azure.microsoft_recoveryservices.UpgradeDetails\x12>\n\x03sku\x18\t \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_recoveryservices.Sku\x12M\n\x0bsystem_data\x18\n \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_recoveryservices.SystemData\x12L\n\x04tags\x18\x0b \x03(\x0b\x32>.oak9.tython.azure.microsoft_recoveryservices.Vaults.TagsEntry\x12]\n\x13vaults_certificates\x18\x0c \x03(\x0b\x32@.oak9.tython.azure.microsoft_recoveryservices.VaultsCertificates\x12l\n\x1bvaults_extended_information\x18\r \x03(\x0b\x32G.oak9.tython.azure.microsoft_recoveryservices.VaultsExtendedInformation\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\nSystemData\x12\x12\n\ncreated_at\x18\x01 \x01(\t\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x17\n\x0f\x63reated_by_type\x18\x03 \x01(\t\x12\x18\n\x10last_modified_at\x18\x04 \x01(\t\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x1d\n\x15last_modified_by_type\x18\x06 \x01(\t\"Q\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\x0c\n\x04tier\x18\x05 \x01(\t\"\x1e\n\x0eUpgradeDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\"*\n\x1aVaultPropertiesMoveDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf5\x01\n\x19VaultPropertiesEncryption\x12!\n\x19infrastructure_encryption\x18\x01 \x01(\t\x12R\n\x0ckek_identity\x18\x02 \x01(\x0b\x32<.oak9.tython.azure.microsoft_recoveryservices.CmkKekIdentity\x12\x61\n\x14key_vault_properties\x18\x03 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_recoveryservices.CmkKeyVaultProperties\"(\n\x15\x43mkKeyVaultProperties\x12\x0f\n\x07key_uri\x18\x01 \x01(\t\"V\n\x0e\x43mkKekIdentity\x12\x1e\n\x16user_assigned_identity\x18\x01 \x01(\t\x12$\n\x1cuse_system_assigned_identity\x18\x02 \x01(\x08\"\xd5\x01\n\x0cIdentityData\x12\x0c\n\x04type\x18\x01 \x01(\t\x12x\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32V.oak9.tython.azure.microsoft_recoveryservices.IdentityData.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_recoveryservices_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VAULTS_TAGSENTRY._options = None
  _VAULTS_TAGSENTRY._serialized_options = b'8\001'
  _IDENTITYDATA_USERASSIGNEDIDENTITIESENTRY._options = None
  _IDENTITYDATA_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_RECOVERYSERVICES._serialized_start=115
  _MICROSOFT_RECOVERYSERVICES._serialized_end=213
  _VAULTSEXTENDEDINFORMATION._serialized_start=216
  _VAULTSEXTENDEDINFORMATION._serialized_end=429
  _VAULTSCERTIFICATES._serialized_start=432
  _VAULTSCERTIFICATES._serialized_end=563
  _VAULTS._serialized_start=566
  _VAULTS._serialized_end=1502
  _VAULTS_TAGSENTRY._serialized_start=1459
  _VAULTS_TAGSENTRY._serialized_end=1502
  _SYSTEMDATA._serialized_start=1505
  _SYSTEMDATA._serialized_end=1665
  _SKU._serialized_start=1667
  _SKU._serialized_end=1748
  _UPGRADEDETAILS._serialized_start=1750
  _UPGRADEDETAILS._serialized_end=1780
  _VAULTPROPERTIESMOVEDETAILS._serialized_start=1782
  _VAULTPROPERTIESMOVEDETAILS._serialized_end=1824
  _VAULTPROPERTIESENCRYPTION._serialized_start=1827
  _VAULTPROPERTIESENCRYPTION._serialized_end=2072
  _CMKKEYVAULTPROPERTIES._serialized_start=2074
  _CMKKEYVAULTPROPERTIES._serialized_end=2114
  _CMKKEKIDENTITY._serialized_start=2116
  _CMKKEKIDENTITY._serialized_end=2202
  _IDENTITYDATA._serialized_start=2205
  _IDENTITYDATA._serialized_end=2418
  _IDENTITYDATA_USERASSIGNEDIDENTITIESENTRY._serialized_start=2357
  _IDENTITYDATA_USERASSIGNEDIDENTITIESENTRY._serialized_end=2418
# @@protoc_insertion_point(module_scope)
